package com.dgtly.wxportal.service.impl;

import java.util.List;
import org.springframework.stereotype.Service;
import com.dgtly.wxportal.mapper.HelpCenterMapper;
import com.dgtly.wxportal.domain.HelpCenter;
import com.dgtly.wxportal.service.IHelpCenterService;
import com.dgtly.common.core.text.Convert;

import javax.annotation.Resource;

/**
 * 帮助中心Service业务层处理
 * 
 * @author dgtly
 * @date 2020-12-09
 */
@Service
public class HelpCenterServiceImpl implements IHelpCenterService 
{
    @Resource
    private HelpCenterMapper helpCenterMapper;

    /**
     * 查询帮助中心
     * 
     * @param id 帮助中心ID
     * @return 帮助中心
     */
    @Override
    public HelpCenter selectHelpCenterById(Long id)
    {
        return helpCenterMapper.selectHelpCenterById(id);
    }

    /**
     * 查询帮助中心列表
     * 
     * @param helpCenter 帮助中心
     * @return 帮助中心
     */
    @Override
    public List<HelpCenter> selectHelpCenterList(HelpCenter helpCenter)
    {
        return helpCenterMapper.selectHelpCenterList(helpCenter);
    }

    /**
     * 新增帮助中心
     * 
     * @param helpCenter 帮助中心
     * @return 结果
     */
    @Override
    public int insertHelpCenter(HelpCenter helpCenter)
    {
        return helpCenterMapper.insertHelpCenter(helpCenter);
    }

    /**
     * 修改帮助中心
     * 
     * @param helpCenter 帮助中心
     * @return 结果
     */
    @Override
    public int updateHelpCenter(HelpCenter helpCenter)
    {
        return helpCenterMapper.updateHelpCenter(helpCenter);
    }

    /**
     * 删除帮助中心对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteHelpCenterByIds(String ids)
    {
        return helpCenterMapper.deleteHelpCenterByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除帮助中心信息
     * 
     * @param id 帮助中心ID
     * @return 结果
     */
    @Override
    public int deleteHelpCenterById(Long id)
    {
        return helpCenterMapper.deleteHelpCenterById(id);
    }
}
